/* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */

#ifndef MELEEWEAPON_H
#define MELEEWEAPON_H

#include "Weapon.h"

class CMeleeWeapon: public CWeapon
{
	CR_DECLARE(CMeleeWeapon)
public:
	CMeleeWeapon(CUnit* owner, const WeaponDef* def);

private:
	bool HaveFreeLineOfFire(const float3 pos, const SWeaponTarget& trg) const override final;
	void FireImpl(const bool scriptCall) override final;
};

#endif /* MELEEWEAPON_H */
